==> SD35B_0.03.0_src.tar.gz: Sd35b/decoder/CommandDriverJ.cpp <==
/*
 * CommandDriverJ.cpp
 *		- "ALICE SOFT System3.x" compatible scenario decoder SD35
 *
 * Copyright (C) 1999 Atsushi Mizuguchi  All rights reserved.
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
 * 02111-1307, USA
 * 
 * 
 *      99/05/24 KISAKA Toshihiro       modify for mwcc compatiblility
 *
 */

#include "stdafx.h"
#include "CommandDriver.h"

#include "ScenarioDecoder.h"
#include "ScenarioParser.h"
#include "ExpressionDriver.h"
#include "GraphicDriver.h"

#if (!__MWERKS__ || defined(MSIPL_USING_NAMESPACE))
using namespace ALSD;
using namespace ALSD_CMDDRV;
#endif
/**********************************************************************
	J command
**********************************************************************/
void CCommandDriver::_CommandJ(void)
{
	switch( m_lpSD->GetParser()->GetC() ){
		case 0:
			CommandJ0(); break;
		case 1:
			CommandJ1(); break;
		case 2:
			CommandJ2(); break;
		case 3:
			CommandJ3(); break;
		case 4:
			CommandJ4(); break;
		default:
			throw EALSD_Msg( "error: J? unknown command\n" );
			break;
	}
}

/**********************************************************************
	΍Ww P񂾂
**********************************************************************/
void CCommandDriver::CommandJ0( void )
{
	long x = m_lpED->GetExpValue();
	long y = m_lpED->GetExpValue();

	m_lpGD->SetLoadCGOpt( x, y, 0, true );
	TRACE( "command:J0(...)\n" );	
}
/**********************************************************************
	΍Ww P񂾂
**********************************************************************/
void CCommandDriver::CommandJ1( void )
{
	long x = m_lpED->GetExpValue();
	long y = m_lpED->GetExpValue();

	m_lpGD->SetLoadCGOpt( x, y, 1, true );
	TRACE( "command:J1(...)\n" );	
}
/**********************************************************************
	΍Ww
**********************************************************************/
void CCommandDriver::CommandJ2( void )
{
	long x = m_lpED->GetExpValue();
	long y = m_lpED->GetExpValue();

	m_lpGD->SetLoadCGOpt( x, y, 0, false );
	TRACE( "command:J2(...)\n" );	
}
/**********************************************************************
	΍Ww
**********************************************************************/
void CCommandDriver::CommandJ3( void )
{
	long x = m_lpED->GetExpValue();
	long y = m_lpED->GetExpValue();

	m_lpGD->SetLoadCGOpt( x, y, 1, false );
	TRACE( "command:J3(...)\n" );	
}
/**********************************************************************
	Ww
**********************************************************************/
void CCommandDriver::CommandJ4( void )
{
	m_lpGD->SetLoadCGOpt( 0, 0, -1, false );
	TRACE( "command:J4(...)\n" );	
}

==> SD35B_0.03.1_src.tar.gz: Sd35b/decoder/CommandDriverJ.cpp <==
/*
 * CommandDriverJ.cpp
 *		- "ALICE SOFT System3.x" compatible scenario decoder SD35
 *
 * Copyright (C) 1999 Atsushi Mizuguchi  All rights reserved.
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
 * 02111-1307, USA
 * 
 * 
 *      99/05/24 KISAKA Toshihiro       modify for mwcc compatiblility
 *
 */

#include "stdafx.h"
#include "CommandDriver.h"

#include "ScenarioDecoder.h"
#include "ScenarioParser.h"
#include "ExpressionDriver.h"
#include "GraphicDriver.h"

#if (!__MWERKS__ || defined(MSIPL_USING_NAMESPACE))
using namespace ALSD;
using namespace ALSD_CMDDRV;
#endif
/**********************************************************************
	J command
**********************************************************************/
void CCommandDriver::_CommandJ(void)
{
	switch( m_lpSD->GetParser()->GetC() ){
		case 0:
			CommandJ0(); break;
		case 1:
			CommandJ1(); break;
		case 2:
			CommandJ2(); break;
		case 3:
			CommandJ3(); break;
		case 4:
			CommandJ4(); break;
		default:
			throw EALSD_Msg( "error: J? unknown command\n" );
			break;
	}
}

/**********************************************************************
	΍Ww P񂾂
**********************************************************************/
void CCommandDriver::CommandJ0( void )
{
	long x = m_lpED->GetExpValue();
	long y = m_lpED->GetExpValue();

	m_lpGD->SetLoadCGOpt( x, y, 0, true );
	TRACE( "command:J0(%d, %d)\n", x, y );	
}
/**********************************************************************
	΍Ww P񂾂
**********************************************************************/
void CCommandDriver::CommandJ1( void )
{
	long x = m_lpED->GetExpValue();
	long y = m_lpED->GetExpValue();

	m_lpGD->SetLoadCGOpt( x, y, 1, true );
	TRACE( "command:J1(...)\n" );	
}
/**********************************************************************
	΍Ww
**********************************************************************/
void CCommandDriver::CommandJ2( void )
{
	long x = m_lpED->GetExpValue();
	long y = m_lpED->GetExpValue();

	m_lpGD->SetLoadCGOpt( x, y, 0, false );
	TRACE( "command:J2(...)\n" );	
}
/**********************************************************************
	΍Ww
**********************************************************************/
void CCommandDriver::CommandJ3( void )
{
	long x = m_lpED->GetExpValue();
	long y = m_lpED->GetExpValue();

	m_lpGD->SetLoadCGOpt( x, y, 1, false );
	TRACE( "command:J3(...)\n" );	
}
/**********************************************************************
	Ww
**********************************************************************/
void CCommandDriver::CommandJ4( void )
{
	m_lpGD->SetLoadCGOpt( 0, 0, -1, false );
	TRACE( "command:J4(...)\n" );	
}
